@@ -1,3 +1,7 @@
+"""
+Route the request to the appropriate parser based on file type.
+"""
+
 import os
 import importlib
 
@@ -8,8 +12,13 @@ EXTENSION_SYNONYMS = {
     ".jpeg": ".jpg"
 }
 
+# default encoding that is returned by the process method. specify it
+# here so the default is used on both the process function and also by
+# the command line interface
+DEFAULT_ENCODING = 'utf_8'
 
-def process(filename, **kwargs):
+
+def process(filename, encoding=DEFAULT_ENCODING, **kwargs):
     """This is the core function used for parsing. It routes the filename
     to the appropriate parser and returns the result.
     """
@@ -21,7 +30,7 @@ def process(filename, **kwargs):
     # get the filename extension, which is something like .docx for
     # example, and import the module dynamically using importlib. This
     # is a relative import so the name of the package is necessary
-    root, ext = os.path.splitext(filename)
+    _, ext = os.path.splitext(filename)
     ext = ext.lower()
 
     # check the EXTENSION_SYNONYMS dictionary
@@ -30,11 +39,16 @@ def process(filename, **kwargs):
     # to avoid conflicts with packages that are installed globally
     # (e.g. python's json module), all extension parser modules have
     # the _parser extension
-    module = ext + '_parser'
+    rel_module = ext + '_parser'
+    module_name = rel_module[1:]
 
-    try:
-        filetype_module = importlib.import_module(module, 'textract.parsers')
-    except ImportError, e:
+    # if this module name doesn't exist in this directory it isn't
+    # currently supported
+    this_dir = os.path.dirname(os.path.abspath(__file__))
+    if not os.path.exists(os.path.join(this_dir, module_name + '.py')):
         raise exceptions.ExtensionNotSupported(ext)
 
-    return filetype_module.extract(filename, **kwargs)
+    # do the extraction
+    filetype_module = importlib.import_module(rel_module, 'textract.parsers')
+    parser = filetype_module.Parser()
+    return parser.process(filename, encoding, **kwargs)
